@@ -2,7 +2,7 @@ from django.core.mail import send_mail, EmailMultiAlternatives
 from core.settings import EMAIL_HOST_USER
 
 
-def send_email(subject, message, to):
+def send_simple_email(subject, message, to):
     recipient_list = get_recipient_list(to)
     if message is not None:
         send_mail(subject=subject, message=message, from_email=EMAIL_HOST_USER, recipient_list=recipient_list,
