@@ -3,6 +3,14 @@ class JSUtils {
         return json == null || Object.keys(json).length === 0;
     }
 
+    static formToJSON(elements) {
+        return [].reduce.call(elements, (data, element) => {
+                data[element.name] = element.value;
+                return data;
+            }, {}
+        );
+    }
+
     static existsElement(idElement) {
         return document.contains(document.getElementById(idElement))
     }
@@ -40,6 +48,28 @@ class JSUtils {
         return false;
     }
 
+    /**
+     *
+     * @param tagName HTML Element Tag
+     * @param elementId Element ID
+     * @param classList List of CSS Classes
+     * @param html HTML Content
+     */
+    static buildElement(tagName, elementId, classList, html) {
+        try {
+            let childElement = document.createElement(tagName);
+            if (elementId != null) {
+                childElement.id = elementId
+            }
+            if (classList != null) {
+                childElement.classList.add(...classList)
+            }
+            childElement.innerHTML = html
+        } catch (e) {
+            throw new Error(e)
+        }
+    }
+
     /**
      *
      * @param tagName HTML Element Tag
@@ -81,110 +111,6 @@ class JSUtils {
     }
 }
 
-class DateUtils {
-    static date = new Date()
-
-    /**
-     * Get a month of year [0-11] and returns -1 if index out of range
-     * @param index
-     * @returns {number|any}
-     */
-    static getMonths(index) {
-        const monthMap = new Map()
-        monthMap.set(0, 'Janeiro');
-        monthMap.set(1, 'Fevereiro');
-        monthMap.set(2, 'Março');
-        monthMap.set(3, 'Abril');
-        monthMap.set(4, 'Maio');
-        monthMap.set(5, 'Junho');
-        monthMap.set(6, 'Julho');
-        monthMap.set(7, 'Agosto');
-        monthMap.set(8, 'Setembro');
-        monthMap.set(9, 'Outubro');
-        monthMap.set(10, 'Novembro');
-        monthMap.set(11, 'Dezembro');
-        return index < 0 || index > monthMap.size ? -1 : monthMap.get(index)
-    }
-
-    static getMonthDays(selectors) {
-        return DOMUtils.getElementByQS(selectors);
-    }
-
-    static getLastDay() {
-        return new Date(this.date.getFullYear(), this.date.getMonth() + 1, 0).getMonth()
-    }
-
-    static getPrevLastDay() {
-        return new Date(this.date.getFullYear(), this.date.getMonth(), 0).getMonth()
-    }
-}
-
-
-class AjaxUtils {
-    static refresh(idElement) {
-        $(`#${idElement}`).load(window.location.href + ` #${idElement}`);
-    }
-
-    static refreshContainer() {
-        this.refresh('container')
-    }
-
-}
-
-
-class ModalUtils {
-
-    static openModal(idModal) {
-        $(`#${idModal}`).modal('show');
-    }
-
-    static closeModal(idModal) {
-        $(`#${idModal}`).modal('hide');
-    }
-
-    static closeAndRemoveModal(idModal, idContainerModal) {
-        this.closeModal(idModal);
-        JSUtils.removeById(idContainerModal);
-    }
-
-    static appendChildModalToBody(idContainerModal, idModal, idForm, titleModal, modalBody, cancelFuncName, confirmFuncName) {
-        let divContainerModal = document.createElement('div')
-        divContainerModal.id = idContainerModal
-        divContainerModal.innerHTML = this.baseContainer(idModal, idForm, titleModal, modalBody, cancelFuncName, confirmFuncName)
-        document.body.appendChild(divContainerModal)
-    }
-
-    /**
-     *
-     * @param idModal String
-     * @param idForm String
-     * @param titleModal String
-     * @param modalBody htmlContent
-     * @param cancelFuncName functionName();
-     * @param confirmFuncName functionName();
-     * @returns {string}
-     */
-    static baseContainer(idModal, idForm, titleModal, modalBody, cancelFuncName, confirmFuncName) {
-        return `<div class="modal fade" id="${idModal}" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
-                    data-focus-on="input:first">
-                    <form id="${idForm}" name="${idForm}">
-                        <div class="modal-dialog">
-                            <div class="modal-content">
-                                <div class="modal-header">
-                                    <h5 id="title_modal" class="modal-title">${titleModal === null ? '' : titleModal}</h5>
-                                </div>
-                                <div class="modal-body">${modalBody}</div>
-                                <div class="modal-footer">
-                                    <button type="button" class="btn btn-sm btn-outline-primary" data-bs-toggle="modal" href="#${idModal}"
-                                     ${cancelFuncName == null ? '' : 'onclick="' + cancelFuncName + '"'}>Cancelar</button>
-                                    <button type="button" class="btn btn-sm btn-primary" onclick="${confirmFuncName}">Confirmar</button>
-                                </div>
-                            </div>
-                        </div>
-                    </form>
-                </div>`
-    }
-}
 
 class DjangoUtils {
     static getCookie(name) {
@@ -205,8 +131,8 @@ class DjangoUtils {
 }
 
 class SpinnerUtils {
-    static showSpinner(idSpinner = 'loading', idContainer = 'container') {
-        JSUtils.appendChild('div', idSpinner, null, HTMLUtils.getSpinner(), idContainer)
+    static showSpinner(idSpinner = 'loading', idContainer = 'container', message = 'Carregando...') {
+        JSUtils.appendChild('div', idSpinner, null, HTMLUtils.getSpinner(message), idContainer)
     }
 
     static hideSpinner(idSpinner = 'loading') {
@@ -271,11 +197,10 @@ class HTMLUtils {
                 </div>`
     }
 
-    static getSpinner(message = 'loading') {
-        return `
-            <div class="btn btn-primary position-fixed bottom-0 end-0 p-2 mb-2 me-2" style="cursor: default">
+    static getSpinner(message) {
+        return `<div class="btn btn-primary position-fixed bottom-0 end-0 p-2 mb-2 me-2" style="cursor: default">
             <span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>
-                ${message}
+                ${message === null ? 'Loading...' : message}
             </div> `
     }
 }
@@ -332,6 +257,6 @@ class FetchUtils {
 
     static afterGetEventListenerThenFetchHandlerGet(json) {
         JSUtils.replaceBrowserUrl(json['url'])
-        AjaxUtils.refresh('container');
+        Jquery.refreshContainer();
     }
 }
\ No newline at end of file
